@@ -1,4 +1,8 @@
-__version__ = '0.13.0'
+"""
+rabbitpy, a pythonic RabbitMQ client
+
+"""
+__version__ = '0.14.0'
 version = __version__
 
 DEBUG = False
@@ -8,15 +12,25 @@ import logging
 try:
     from logging import NullHandler
 except ImportError:
-    # Python 2.6 does not have a NullHandler
     class NullHandler(logging.Handler):
+        """Python 2.6 does not have a NullHandler"""
         def emit(self, record):
+            """Emit a record
+
+            :param record record: The record to emit
+
+            """
             pass
 
 logging.getLogger('rabbitpy').addHandler(NullHandler())
 
 from rabbitpy.connection import Connection
+from rabbitpy.channel import Channel
 from rabbitpy.exchange import Exchange
+from rabbitpy.exchange import DirectExchange
+from rabbitpy.exchange import FanoutExchange
+from rabbitpy.exchange import HeadersExchange
+from rabbitpy.exchange import TopicExchange
 from rabbitpy.message import Message
 from rabbitpy.amqp_queue import Queue
 from rabbitpy.tx import Tx
