@@ -1,11 +1,5 @@
 """
-The Channel object is the communications object used by Exchanges, Messages,
-Queues, and Transactions. It is created by invoking the
-:py:meth:`rabbitpy.connection.Connection.channel` method. It can act as a context
-manager, allowing for quick shorthand use:
 
-    with connection.channel():
-       # Do something
 
 """
 import logging
@@ -26,8 +20,16 @@ LOGGER = logging.getLogger(__name__)
 
 
 class Channel(base.AMQPChannel):
-    """The Channel class implements the channel communication layer on top of
-    the Connection object, which is responsible for creating new channels.
+    """The Channel object is the communications object used by Exchanges,
+    Messages, Queues, and Transactions. It is created by invoking the
+    :py:meth:`rabbitpy.Connection.channel()
+    <rabbitpy.connection.Connection.channel>` method. It can act as a context
+    manager, allowing for quick shorthand use:
+
+    .. code:: python
+
+        with connection.channel():
+           # Do something
 
     To create a new channel, invoke
     py:meth:`rabbitpy.connection.Connection.channel`
@@ -72,8 +74,8 @@ class Channel(base.AMQPChannel):
         return self
 
     def __exit__(self, exc_type, exc_val, unused_exc_tb):
-        """When leaving the context, examine why the context is leaving, if it's
-         an exception or what.
+        """When leaving the context, examine why the context is leaving, if
+        it's  an exception or what.
 
         """
         if exc_val:
@@ -101,7 +103,7 @@ class Channel(base.AMQPChannel):
         # Empty the queue and nack the max id (and all previous)
         if self._consumers:
             if DEBUG:
-                LOGGER.debug('Channel %i purging read queue & nacking messages',
+                LOGGER.debug('Channel %i purging read queue & nacking msgs',
                              self._channel_id)
             delivery_tag = 0
             discard_counter = 0
@@ -144,8 +146,8 @@ class Channel(base.AMQPChannel):
         return self._maximum_frame_size
 
     def on_remote_close(self, value):
-        """Invoked by rabbitpy.connection.Connection when a remote channel close
-        is issued.
+        """Invoked by rabbitpy.connection.Connection when a remote channel
+        close is issued.
 
         :param value: The Channel.Close method frame
         :type value: pamqp.specification.Channel.Close
@@ -252,16 +254,24 @@ class Channel(base.AMQPChannel):
         frame_value = specification.Basic.Cancel(consumer_tag=obj.consumer_tag)
         self._write_frame(frame_value)
 
-    def _consume(self, obj, no_ack):
+    def _consume(self, obj, no_ack, priority):
         """Register a Queue object as a consumer, issuing Basic.Consume.
 
         :param rabbitpy.amqp_queue.Queue obj: The queue to consume
         :param bool no_ack: no_ack mode
+        :param int priority: Consumer priority
+        :raises: ValueError
 
         """
+        args = dict()
+        if priority is not None:
+            if not isinstance(priority, int):
+                raise ValueError('Consumer priority must be an int')
+            args['x-priority'] = priority
         self.rpc(specification.Basic.Consume(queue=obj.name,
                                              consumer_tag=obj.consumer_tag,
-                                             no_ack=no_ack))
+                                             no_ack=no_ack,
+                                             arguments=args))
         self._consumers.append(obj)
 
     def _consume_message(self):
@@ -274,14 +284,16 @@ class Channel(base.AMQPChannel):
         return self._wait_for_content_frames(frame_value)
 
     def _create_message(self, method_frame, header_frame, body):
-        """Create a message instance with the channel it was received on and the
-        dictionary of message parts. Will return None if no message can be
+        """Create a message instance with the channel it was received on and
+        the dictionary of message parts. Will return None if no message can be
         created.
 
         :param pamqp.specification.Frame method_frame: The method frame value
-        :param pamqp.header.ContentHeader|None header_frame: Header frame value
-        :param str|None body: The message body
-        :rtype: rabbitpy.message.Message|None
+        :param header_frame: Header frame value
+        :type header_frame: pamqp.header.ContentHeader or None
+        :param body: The message body
+        :type body: str or None
+        :rtype: rabbitpy.message.Message or None
 
         """
         if not method_frame:
@@ -326,8 +338,8 @@ class Channel(base.AMQPChannel):
                                           requeue=True))
 
     def _process_basic_return(self, msg):
-        """Raise a MessageReturnedException so the publisher can handle returned
-        messages.
+        """Raise a MessageReturnedException so the publisher can handle
+        returned messages.
 
         :param pmqid.message.message msg: The message to add
         :raises: rabbitpy.exceptions.MessageReturnedException
